# coding: utf-8

"""
Trading API

API for automated trading and exchange interface

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self


class FuturesBalance(BaseModel):
    """
    Model for futures balance
    """  # noqa: E501

    api_key_id: StrictStr = Field(description="API key ID", alias="apiKeyId")
    asset: StrictStr = Field(description="Asset/Currency code")
    balance: Union[StrictFloat, StrictInt] = Field(description="Total balance/equity")
    available: Union[StrictFloat, StrictInt] = Field(
        description="Available balance for trading/withdrawal"
    )
    unrealized_pnl: Union[StrictFloat, StrictInt] = Field(
        description="Unrealized profit and loss", alias="unrealizedPnl"
    )
    used_margin: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None, alias="usedMargin"
    )
    frozen_amount: Optional[Union[StrictFloat, StrictInt]] = Field(
        default=None, alias="frozenAmount"
    )
    __properties: ClassVar[List[str]] = [
        "apiKeyId",
        "asset",
        "balance",
        "available",
        "unrealizedPnl",
        "usedMargin",
        "frozenAmount",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of FuturesBalance from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if used_margin (nullable) is None
        # and model_fields_set contains the field
        if self.used_margin is None and "used_margin" in self.model_fields_set:
            _dict["usedMargin"] = None

        # set to None if frozen_amount (nullable) is None
        # and model_fields_set contains the field
        if self.frozen_amount is None and "frozen_amount" in self.model_fields_set:
            _dict["frozenAmount"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of FuturesBalance from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "apiKeyId": obj.get("apiKeyId"),
                "asset": obj.get("asset"),
                "balance": obj.get("balance"),
                "available": obj.get("available"),
                "unrealizedPnl": obj.get("unrealizedPnl"),
                "usedMargin": obj.get("usedMargin"),
                "frozenAmount": obj.get("frozenAmount"),
            }
        )
        return _obj
