# coding: utf-8

"""
Trading API

API for automated trading and exchange interface

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BotStatus(str, Enum):
    """
    BotStatus
    """

    """
    allowed enum values
    """
    RUNNING = "running"
    STOPPING = "stopping"
    STOPPED = "stopped"
    DELETED = "deleted"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BotStatus from a JSON string"""
        return cls(json.loads(json_str))
