# coding: utf-8

# flake8: noqa

"""
Marketcap Service API

API for retrieving historical marketcap data, available exchanges, and indicators.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from crypticorn.metrics.client.api.exchanges_api import ExchangesApi
from crypticorn.metrics.client.api.indicators_api import IndicatorsApi
from crypticorn.metrics.client.api.logs_api import LogsApi
from crypticorn.metrics.client.api.marketcap_api import MarketcapApi
from crypticorn.metrics.client.api.markets_api import MarketsApi
from crypticorn.metrics.client.api.status_api import StatusApi
from crypticorn.metrics.client.api.tokens_api import TokensApi

# import ApiClient
from crypticorn.metrics.client.api_response import ApiResponse
from crypticorn.metrics.client.api_client import ApiClient
from crypticorn.metrics.client.configuration import Configuration
from crypticorn.metrics.client.exceptions import OpenApiException
from crypticorn.metrics.client.exceptions import ApiTypeError
from crypticorn.metrics.client.exceptions import ApiValueError
from crypticorn.metrics.client.exceptions import ApiKeyError
from crypticorn.metrics.client.exceptions import ApiAttributeError
from crypticorn.metrics.client.exceptions import ApiException

# import models into sdk package
from crypticorn.metrics.client.models.exception_detail import ExceptionDetail
from crypticorn.metrics.client.models.severity import Severity
from crypticorn.metrics.client.models.time_interval import TimeInterval
from crypticorn.metrics.client.models.trading_status import TradingStatus
