# coding: utf-8

# flake8: noqa

"""
Trading API

API for automated trading and exchange interface

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# import apis into sdk package
from crypticorn.trade.client.api.api_keys_api import APIKeysApi
from crypticorn.trade.client.api.bots_api import BotsApi
from crypticorn.trade.client.api.exchanges_api import ExchangesApi
from crypticorn.trade.client.api.futures_trading_panel_api import FuturesTradingPanelApi
from crypticorn.trade.client.api.notifications_api import NotificationsApi
from crypticorn.trade.client.api.orders_api import OrdersApi
from crypticorn.trade.client.api.status_api import StatusApi
from crypticorn.trade.client.api.strategies_api import StrategiesApi
from crypticorn.trade.client.api.trading_actions_api import TradingActionsApi

# import ApiClient
from crypticorn.trade.client.api_response import ApiResponse
from crypticorn.trade.client.api_client import ApiClient
from crypticorn.trade.client.configuration import Configuration
from crypticorn.trade.client.exceptions import OpenApiException
from crypticorn.trade.client.exceptions import ApiTypeError
from crypticorn.trade.client.exceptions import ApiValueError
from crypticorn.trade.client.exceptions import ApiKeyError
from crypticorn.trade.client.exceptions import ApiAttributeError
from crypticorn.trade.client.exceptions import ApiException

# import models into sdk package
from crypticorn.trade.client.models.action_model import ActionModel
from crypticorn.trade.client.models.bot_model import BotModel
from crypticorn.trade.client.models.bot_status import BotStatus
from crypticorn.trade.client.models.exception_detail import ExceptionDetail
from crypticorn.trade.client.models.exchange_key_model import ExchangeKeyModel
from crypticorn.trade.client.models.execution_ids import ExecutionIds
from crypticorn.trade.client.models.futures_balance import FuturesBalance
from crypticorn.trade.client.models.futures_trading_action import FuturesTradingAction
from crypticorn.trade.client.models.margin_mode import MarginMode
from crypticorn.trade.client.models.notification_model import NotificationModel
from crypticorn.trade.client.models.order_model import OrderModel
from crypticorn.trade.client.models.order_status import OrderStatus
from crypticorn.trade.client.models.post_futures_action import PostFuturesAction
from crypticorn.trade.client.models.spot_trading_action import SpotTradingAction
from crypticorn.trade.client.models.strategy_exchange_info import StrategyExchangeInfo
from crypticorn.trade.client.models.strategy_model_input import StrategyModelInput
from crypticorn.trade.client.models.strategy_model_output import StrategyModelOutput
from crypticorn.trade.client.models.tpsl import TPSL
from crypticorn.trade.client.models.trading_action_type import TradingActionType
